===============================
parthsql
===============================

.. image:: https://img.shields.io/pypi/v/parthsql.svg
        :target: https://pypi.python.org/pypi/parthsql

.. image:: https://img.shields.io/travis/ParthKolekar/parthsql.svg
        :target: https://travis-ci.org/ParthKolekar/parthsql

.. image:: https://readthedocs.org/projects/parthsql/badge/?version=latest
        :target: https://readthedocs.org/projects/parthsql/?badge=latest
        :alt: Documentation Status


A mini SQL query engine written in Python

* Free software: ISC license
* Documentation: https://parthsql.readthedocs.org.

Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
